function out = lab1_sys3(in)

%function out = lab1_sys3(in)
%
% LAB1_SYS3  --  Adds saturating distortion to a signal
%
% Input parameters:
%   in   -- the signal to be distorted
%
% Output parameters:
%   out  -- the distorted signal

% Written by Mark Bartsch, Winter 2002
% Modification History:
%    8/16/02  --  Added modification history (MB)



x = -5:.01:5;
y = tanh(2*x)/2;
out = interp1(x,y,in,'linear');
